# -*- coding:utf-8 -*-
"""
对不同平台提供原生快速删除方法

例：
>>>import os
>>>from cgai_io.Delete import delfile,deldir,delall
>>>
>>># #删除文件
>>># path = r'\\192.168.1.248\3d\temp\a\cmd_mac.py'
>>># delfile(path)
>>>
>>>
>>># #删除文件夹
>>># path = r'D:\BaiduNetdiskDownload\AA'
>>># deldir(path,keep_dir=True)
>>>
>>>
>>>#无论文件或文件夹都直接删除
>>># path = r'D:\BaiduNetdiskDownload\ktk_103024'
>>># delall(path)
>>>


"""

from ._util import *
import subprocess

def delfile(file_path,wait=False):
    """
    删除文件
    :param file_path: 文件路径
    :param wait: 是否阻塞已等待完成
    :return:
    """
    p = None
    if iswin():
        if isfile(file_path):
            p = subprocess.Popen(['del','/f','/s','/q',file_path.replace('/','\\')],shell=True)
        else:
            print("删除对象非文件")
    else:
        if file_path not in ['/','/*']:
            if isfile(file_path):
                p = subprocess.Popen(['rm','-rf',file_path],shell=False)
            else:
                print("删除对象非文件")

    if p and wait:
        p.wait()


def deldir(dir_path,keep_dir=False,wait=False):
    """
    删除文件目录
    :param dir_path: 文件目录路径
    :param keep_dir: 保持源目录结构
    :param wait: 是否阻塞已等待完成
    :return:
    """
    p = None
    if iswin():
        if isdir(dir_path):
            if keep_dir:
                p = subprocess.Popen(['del','/f','/s','/q',dir_path.replace('/','\\')],shell=True)
            else:
                p = subprocess.Popen(['rd','/s','/q',dir_path.replace('/','\\')],shell=True)
        else:
            print("删除对象非文件目录")
    else:
        if isdir(dir_path):
            if dir_path not in ['/','/*']:  #禁止删全家
                if keep_dir:
                    p = subprocess.Popen(['find','path','-type','q','-exec','rm',dir_path],shell=False)
                else:
                    os.popen("rm -rf %s" % (dir_path.replace('\\', '/')))
                   
        else:
            print("删除对象非文件目录")
    if p and wait:
        p.wait()


def delall(path,keep_dir=False,wait=False):
    """
    无论文件还是文件目录都删除
    :param path:
    :param keep_dir: 保持源目录结构
    :param wait: 是否阻塞已等待完成
    :return:
    """

    if isfile(path):
        delfile(path,wait)
    elif isdir(path):
        deldir(path,keep_dir,wait)



# -*- coding:utf-8 -*-
"""
该脚本获取各文件信息
"""
import os

UNIT = {'KB':1024,'M':1024*1024,'G':1024*1024*1024}

def getFileSize(path,unit='M'):
    size = 0
    if os.path.isfile(path):
        s = os.path.getsize(path)
        size = s/UNIT.get(unit,1024) if s else 0
    return size






#-*- coding:utf-8 -*-
"""
移动文件或目录
"""
import subprocess
from ._util import *


def mv(src,des,wait=True):
    """
    移动文件或文件夹
    :param src: 源文件或目录
    :param des: 目标文件或目录
    :return:
    """
    if iswin():
        src_file = src.replace('/', '\\')
        des_file = des.replace('/', '\\')
        p = subprocess.Popen(['move',src_file,des_file],shell=True)
    else:
        p = subprocess.Popen(['mv',src_file,des_file],shell=True)

    if wait:
        p.wait()
    
def mvfile(src,des,wait=True):
    """
    移动文件
    :param src: 源文件
    :param des: 目标文件
    :return: 
    """
    if isfile(src):
        mv(src,des,wait)
    else:
        raise Exception("输入非文件")

def mvdir(src,des,wait=True):
    """
    移动文件目录
    :param src: 源文件目录
    :param des: 目标文件目录
    :return:
    """
    if isdir(src):
        mv(src,des,wait)
    else:
        raise Exception("输入非文件目录")



